@@ -194,7 +194,8 @@ QDBusObjectPath cucd::Service::CreateImportFromPeer(const QString& peer_id, cons
     {
         TRACE() << Q_FUNC_INFO << "APP_ID isnt' set, attempting to get it from AppArmor";
         dest_id = aa_profile_id;
-    } else if (aa_profile_id != "unconfined" && dest_id != aa_profile_id) {
+    } else if (aa_profile_id != "unconfined" &&
+        (qgetenv("LOMIRI_CONTENT_HUB_TESTING").isNull() && dest_id != aa_profile_id)) {
         TRACE() << Q_FUNC_INFO << "App with profile '" << aa_profile_id <<
                                   "' said their ID is '" << dest_id << "'";
         sendErrorReply(QDBusError::AccessDenied,
@@ -306,7 +307,8 @@ QDBusObjectPath cucd::Service::CreateExportToPeer(const QString& peer_id, const
     {
         TRACE() << Q_FUNC_INFO << "APP_ID isnt' set, attempting to get it from AppArmor";
         src_id = aa_profile_id;
-    } else if (aa_profile_id != "unconfined" && src_id != aa_profile_id) {
+    } else if (aa_profile_id != "unconfined" &&
+        (qgetenv("LOMIRI_CONTENT_HUB_TESTING").isNull() && src_id != aa_profile_id)) {
         TRACE() << Q_FUNC_INFO << "App with profile '" << aa_profile_id <<
                                   "' said their ID is '" << src_id << "'";
         sendErrorReply(QDBusError::AccessDenied,
@@ -325,7 +327,8 @@ QDBusObjectPath cucd::Service::CreateShareToPeer(const QString& peer_id, const Q
     {
         TRACE() << Q_FUNC_INFO << "APP_ID isnt' set, attempting to get it from AppArmor";
         src_id = aa_profile_id;
-    } else if (aa_profile_id != "unconfined" && src_id != aa_profile_id) {
+    } else if (aa_profile_id != "unconfined" &&
+        (qgetenv("LOMIRI_CONTENT_HUB_TESTING").isNull() && src_id != aa_profile_id)) {
         TRACE() << Q_FUNC_INFO << "App with profile '" << aa_profile_id <<
                                   "' said their ID is '" << src_id << "'";
         sendErrorReply(QDBusError::AccessDenied,
